@@ -26,5 +26,7 @@ exsltRegisterAll (void) {
     exsltMathRegister();
     exsltSetsRegister();
     exsltFuncRegister();
+    exsltStrRegister();
+    exsltDateRegister();
 }
 
