@@ -14,11 +14,15 @@ LIBEXSLT_PUBLIC extern const int exsltLibxmlVersion;
 #define EXSLT_MATH_NAMESPACE ((const xmlChar *) "http://exslt.org/math")
 #define EXSLT_SETS_NAMESPACE ((const xmlChar *) "http://exslt.org/sets")
 #define EXSLT_FUNCTIONS_NAMESPACE ((const xmlChar *) "http://exslt.org/functions")
+#define EXSLT_STRINGS_NAMESPACE ((const xmlChar *) "http://exslt.org/strings")
+#define EXSLT_DATE_NAMESPACE ((const xmlChar *) "http://exslt.org/dates-and-times")
 
 void exsltCommonRegister (void);
 void exsltMathRegister (void);
 void exsltSetsRegister (void);
 void exsltFuncRegister (void);
+void exsltStrRegister (void);
+void exsltDateRegister (void);
 
 void exsltRegisterAll (void);
 
