@@ -145,6 +145,12 @@ xsltFunctionNodeSet(xmlXPathParserContextPtr ctxt, int nargs){
     }
 }
 
+/*
+ * Seems FreeBSD decided not to provide the timezone libc varaible
+ * C.f bug report #59570 http://bugzilla.gnome.org/show_bug.cgi?id=59570
+ */
+#ifndef __FreeBSD__
+
 #if defined(HAVE_MKTIME) && defined(HAVE_LOCALTIME) && defined(HAVE_ASCTIME)
 #define WITH_LOCALTIME
 
@@ -190,7 +196,7 @@ xsltFunctionLocalTime(xmlXPathParserContextPtr ctxt, int nargs) {
     
     str = (char *) obj->stringval;
 
-    /* str = "$Date: 2001/08/14 16:46:18 $" */
+    /* str = "$Date: 2001/09/11 10:47:56 $" */
     memset(digits, 0, sizeof(digits));
     strncpy(digits, str+7, 4);
     field = strtol(digits, NULL, 10);
@@ -262,6 +268,7 @@ xsltFunctionLocalTime(xmlXPathParserContextPtr ctxt, int nargs) {
     valuePush(ctxt, xmlXPathNewString((xmlChar *)result));
 }
 #endif
+#endif /* __FreeBSD__ */
 
 
 /**
