@@ -288,7 +288,7 @@ xsltPrintErrorContext(xsltTransformContextPtr ctxt,
     const xmlChar *name = NULL;
     const char *type = "error";
 
-    if ((node != NULL) && (ctxt != NULL))
+    if ((node == NULL) && (ctxt != NULL))
 	node = ctxt->inst;
 
     if (node != NULL)  {
@@ -552,6 +552,7 @@ xsltComputeSortResult(xsltTransformContextPtr ctxt, xmlNodePtr sort) {
 		}
 	    }
 	} else {
+	    ctxt->state = XSLT_STATE_STOPPED;
 	    results[i] = NULL;
 	}
     }
@@ -885,9 +886,11 @@ xsltSaveResultTo(xmlOutputBufferPtr buf, xmlDocPtr result,
 	    while (child != NULL) {
 		xmlNodeDumpOutput(buf, result, child, 0, (indent == 1),
 			          (const char *) encoding);
-		xmlOutputBufferWriteString(buf, "\n");
+		if (child->type == XML_DTD_NODE)
+		    xmlOutputBufferWriteString(buf, "\n");
 		child = child->next;
 	    }
+	    xmlOutputBufferWriteString(buf, "\n");
 	}
 	xmlOutputBufferFlush(buf);
     }
@@ -1072,29 +1075,7 @@ xsltCalibrateAdjust(long delta) {
 long
 xsltTimestamp(void)
 {
-#ifdef HAVE_GETTIMEOFDAY
-    static struct timeval startup;
-    struct timeval cur;
-    long tics;
-
-    if (calibration < 0) {
-        gettimeofday(&startup, NULL);
-        calibration = 0;
-        calibration = xsltCalibrateTimestamps();
-        gettimeofday(&startup, NULL);
-        return (0);
-    }
-
-    gettimeofday(&cur, NULL);
-    tics = (cur.tv_sec - startup.tv_sec) * XSLT_TIMESTAMP_TICS_PER_SEC;
-    tics += (cur.tv_usec - startup.tv_usec) /
-                          (1000000l / XSLT_TIMESTAMP_TICS_PER_SEC);
-    
-    tics -= calibration;
-    return(tics);
-#else
 #ifdef XSLT_WIN32_PERFORMANCE_COUNTER
-
     BOOL ok;
     LARGE_INTEGER performanceCount;
     LARGE_INTEGER performanceFrequency;
@@ -1122,13 +1103,34 @@ xsltTimestamp(void)
     return (long) (seconds * XSLT_TIMESTAMP_TICS_PER_SEC);
 
 #else /* XSLT_WIN32_PERFORMANCE_COUNTER */
+#ifdef HAVE_GETTIMEOFDAY
+    static struct timeval startup;
+    struct timeval cur;
+    long tics;
+
+    if (calibration < 0) {
+        gettimeofday(&startup, NULL);
+        calibration = 0;
+        calibration = xsltCalibrateTimestamps();
+        gettimeofday(&startup, NULL);
+        return (0);
+    }
+
+    gettimeofday(&cur, NULL);
+    tics = (cur.tv_sec - startup.tv_sec) * XSLT_TIMESTAMP_TICS_PER_SEC;
+    tics += (cur.tv_usec - startup.tv_usec) /
+                          (1000000l / XSLT_TIMESTAMP_TICS_PER_SEC);
+    
+    tics -= calibration;
+    return(tics);
+#else
 
     /* Neither gettimeofday() nor Win32 performance counter available */
 
     return (0);
 
+#endif /* HAVE_GETTIMEOFDAY */
 #endif /* XSLT_WIN32_PERFORMANCE_COUNTER */
-#endif
 }
 
 #define MAX_TEMPLATES 10000
