@@ -9,6 +9,12 @@
 #ifndef __XML_XSLTUTILS_H__
 #define __XML_XSLTUTILS_H__
 
+#if defined(WIN32) && defined(_MSC_VER)
+#include <libxslt/xsltwin32config.h>
+#else
+#include <libxslt/xsltconfig.h>
+#endif
+
 #include <libxml/xpath.h>
 #include <libxml/xmlerror.h>
 #include "xsltInternals.h"
@@ -54,6 +60,30 @@ extern "C" {
 #define IS_XSLT_NAME(n, val)						\
     (xmlStrEqual((n)->name, (const xmlChar *) (val)))
 
+/**
+ * IS_XSLT_REAL_NODE:
+ *
+ * check that a node is a 'real' one: document, element, text or attribute
+ */
+#ifdef LIBXML_DOCB_ENABLED
+#define IS_XSLT_REAL_NODE(n)						\
+    (((n) != NULL) &&							\
+     (((n)->type == XML_ELEMENT_NODE) ||				\
+      ((n)->type == XML_TEXT_NODE) ||					\
+      ((n)->type == XML_ATTRIBUTE_NODE) ||				\
+      ((n)->type == XML_DOCUMENT_NODE) ||				\
+      ((n)->type == XML_HTML_DOCUMENT_NODE) ||				\
+      ((n)->type == XML_DOCB_DOCUMENT_NODE)))
+#else
+#define IS_XSLT_REAL_NODE(n)						\
+    (((n) != NULL) &&							\
+     (((n)->type == XML_ELEMENT_NODE) ||				\
+      ((n)->type == XML_TEXT_NODE) ||					\
+      ((n)->type == XML_ATTRIBUTE_NODE) ||				\
+      ((n)->type == XML_DOCUMENT_NODE) ||				\
+      ((n)->type == XML_HTML_DOCUMENT_NODE)))
+#endif
+
 /*
  * Our own version of namespaced atributes lookup
  */
@@ -64,10 +94,10 @@ xmlChar *	 xsltGetNsProp			(xmlNodePtr node,
 /*
  * XSLT specific error and debug reporting functions
  */
-extern xmlGenericErrorFunc xsltGenericError;
-extern void *xsltGenericErrorContext;
-extern xmlGenericErrorFunc xsltGenericDebug;
-extern void *xsltGenericDebugContext;
+LIBXSLT_PUBLIC extern xmlGenericErrorFunc xsltGenericError;
+LIBXSLT_PUBLIC extern void *xsltGenericErrorContext;
+LIBXSLT_PUBLIC extern xmlGenericErrorFunc xsltGenericDebug;
+LIBXSLT_PUBLIC extern void *xsltGenericDebugContext;
 
 void		xsltPrintErrorContext		(xsltTransformContextPtr ctxt,
 	                                         xsltStylesheetPtr style,
